#loading {
       width: 300px;
       height: 120px;
       background-color: #bfebff;
       position: absolute;
       left: 60%;
       top: 50%;
       margin-top: -150px;
       margin-left: -250px;
       text-align: center;
	   background:url(../images/wait_bg.gif);
}

#bgDiv{
	width:960px;
	height:1250px;
	position:absolute;
	top:0px; 
	left:0px; 
	background:#ffffff; 
	opacity:0.1;
	filter:alpha(opacity=10); 
	z-index:1000;
	}

form{margin:0;}

.all_body {
	width:960px; 
	margin:0 auto; 
	padding: 0; 
	background:#fff;
	color:#333;
	text-align: center;
	position:relative;
	}

.iframe_div{
	float:left;
	width:758px;
	margin-left:0;
	}
	
.iframe_div1{
	float:left;
	width:757px;
	margin-left:0;
	}
	
#iframepage{
	background:#FAFAFA;
	}

body,td,th,button,p,div,textarea,select,input {
    font-family:ËÎÌå, Arial, Helvetica, sans-serif;
	font-size:12px;
	color:#333;}
.textarea{width:640px;height:300px;}

a{font-size:10px; color:#323232; text-decoration:none;}
a:link{font-size:10px; color:#323232; text-decoration:none; }
a:active{font-size:10px;}
a:hover{font-size:10px; color:#323232;  text-decoration:none;}
img{border:0px;}

.buttondiv{
	text-align:center;
	margin-top:20px;
	width:90%;
	}
	
.button{
	background:url(../images/buttonbg.gif) repeat-x;
	border:1px #646464 solid;
	height:20px;
	width:120px;
	line-height:17px;
	text-align:center;
	cursor:pointer;
	margin:12px;
	}
.button01{
	border:1px #646464 solid;
	height:20px;
	width:60px;
	line-height:17px;
	text-align:center;
	cursor:pointer;
	margin:12px;
	}
.button02{
	background: url(../images/buttonbg.gif) repeat-x;
	border:1px #646464 solid;
	height:20px;
	width:60px;
	line-height:17px;
	text-align:center;
	cursor:pointer;
	margin:3px;
	}

.clear{ clear:both;}

/*top logo style*/
#top{
/*	background:url(../images/logoDAWU1023v1.png);*/
	height:66px;
	text-align:center;
	width:960px;
	border-right:1px solid #ec9523;
	}
	
.topTable{width:100%;}

#idLanguageOption{
	background:#dcdcdc;
	border:1px solid #ffffff;
	border-radius:4px;
	}

/*content style start*/
.clear{
	clear:both;
	*height:1px;
	*margin-top:-1px;
	*overflow:hidden;
	}

.content{
	width:960px; 
	margin:0 auto;
	border-right:1px solid #cfcfcf;
	background: #1E90FF;
	position:relative;
	}

.content .left{
	float:left; 
	width:200px; 
	text-align:left;
	}

.contentbody{
	width:758px;
	margin:0;
	padding:0;
	position:static;
	background-color:transparent;
	}
		
/*menu style start*/
    .left_menu1{ font-family:ËÎÌå, Arial, Helvetica, sans-serif; font-size:12px; color:#f08300;  font-weight:bold; }
    .left_menu{     font-family:ËÎÌå, Arial, Helvetica, sans-serif; font-size:12px;  color:#f08300;  font-weight:bold;text-decoration:underline; margin-left:10px; margin-right:10px}
    .left_menu:hover {    font-family:ËÎÌå, Arial, Helvetica, sans-serif; font-size:12px;  color: #FFFFFF; font-weight:bold; text-decoration:underline;cursor:pointer}
	.left img{margin:0 1px 0 1px;}

	.left ul {
		margin:0;
		padding:0;
		list-style:none}
		
	.left li{
		display:block;
		margin:0; 
		color:#FFFFFF;
		font-family:ËÎÌå, Arial, Helvetica, sans-serif;
		font-size:12px;
		padding:3px 0 3px 10px;
		cursor:pointer;
		text-decoration:none;
		text-align:left;
		background:#2C5EA4;
		height:20px;
		}
		
	.model{
		font-size:12px;
		font-family:"ËÎÌå", Arial, Helvetica, sans-serif;
		color:#f08300;
		padding:5px 0 5px 22px;
		}

	.left dl{
		border:solid #fff;
		border-width:0;
		margin:0;
		padding:0px;
		list-style:none;
		line-height:22px;
		color:#FFFFFF;
		}
		
	.left dd{
		margin:0;
		padding:2px 0 2px 24px;
		font-family:ËÎÌå, Arial, Helvetica, sans-serif;
		font-size:12px;
		text-align:left;
		cursor:pointer;
		}

	.left .ddbak{
		background:#2C5EA4;
		}
/*menu style end*/
.right{
	display:none;
	float:right;
	width:170px;
	text-align:left;
	line-height:22px;
	word-break:break-all;word-wrap:break-word;
	}
	
.mainbiao{
		color:#636d81;
		font-family:"ËÎÌå", Arial, Helvetica, sans-serif;
		font-size:14px;
		/*font-weight:bold;*/
		padding:20px 0 8px 0;
		}
.mainbiao1{
		padding:3px 0 8px 0;
		margin-bottom:10px;
		font-size:12px;
		font-family:"ËÎÌå", Arial, Helvetica, sans-serif;}

.contentTable {border-collapse:collapse;height:70%;text-align:center;}

.contentTable td.center{width:740px; text-align:left;padding:5px 5px 5px 16px;}
.contentTable td.center1{width:740px; text-align:left;padding:0px 5px 5px 30px;}
.contentTable td.right{width:170px;line-height:22px;background:#CCCCCC;text-align:left;}
.table01 {border-collapse:collapse;width:90%;}
.table01 td{border-width:1px; 
	border-style:solid; 
	border-color:#cccccc; 
	padding:3px 3px 3px 8px;
	height:20px;  	
	}
.table01 .leftnone{
	border-left:none;
	}
.table01 .rightnone{
	border-right:none;
	}
.table01 .topnone{
	border-top:none;
	}
.table01 .none{
	border-left:none;
	border-right:none;
	}
.table01 td.lable{background:#e9ebf1;font-weight:bold;text-align:left; height:21px;}

/*help style start*/
#showhelp{
	position:absolute;
	left:741px;
	top:8px;
	z-index:2000;
	cursor:pointer;
	}
/*help style end*/
.footer{
	height:33px;
	line-height:33px;
	width:960px;
	background:#0099cc;
    font-family:ËÎÌå, Arial, Helvetica, sans-serif;
    font-size:10px;
	}
	
#version{
	height:30px;
	width:200px;
	font-family:ËÎÌå, Arial, Helvetica, sans-serif;
	font-size:10px;
	font-style:italic;
	color:#ffffff;
	text-align:center;
	position:absolute;
	left:0;
	margin-top:-40px;
	}
	
#helpline{
	position:absolute;
	}

input{ 
    height:18px;  
}
input[type=text]{ 
    height:16px;  
}
input[type=password]{ 
    height:16px;  
}
select{ 
    height:23px;  
}
input[type=radio]{ 
    height:0px;  
	height:20px !important;
	padding:0;
	vertical-align:middle;
}
input[type=checkbox]{ 
    height:0px; 
	height:12px !important; 
}


/*******************************add by ycf**********************************/
div.button-container{
	display: inline-block;
	margin: 0 9px 0 0;

}


div.button-container  .button-button{
	background-color: #2ca2dc;
	min-width: 90px;
	padding:8px 6px 9px;
	border: 0px;
	border-radius: 3px;
	color: #fff;

}

span.button-text{
	line-height: 16px;
	vertical-align: middle;
}
