body,div,dl,dt,dd,ul,ol,li,h1,h2,h3,h4,h5,h6,pre,form,fieldset,input,textarea,p,blockquote,th,td 
{ 
	padding:0;
}
table
{
	border-collapse:collapse;
	border-spacing:0;
}
.tabList .block 
{ 
display: block; 
}
fieldset,img { 
	border:0;
}
address,caption,cite,code,dfn,em,strong,th,var {
	font-style:normal;
	font-weight:normal;
}
ol,ul {
	list-style:none;
}
caption,th {
	text-align:left;
}
h1,h2,h3,h4,h5,h6 {
	font-size:100%;
	font-weight:normal;
}
q:before,q:after {
	content:'';
}
abbr,acronym { border:0;
}
html, body {
/**	background-color:  #CCFFCC;**/
	font-family: Arial, Helvetica, sans-serif;
	font-size: 14px;
	line-height: 18px;
	color: #52697E;
}
body {
	text-align: center;
	overflow: auto;
	width: 100%;
    margin-left: 10px;
}
#periodofvalityend,
#periodofvalitystart
{
    cursor:pointer;
}
.tabsContent {
/**	border: 1px solid #ccc;**/
	border-top: 0px solid;
	width: 698px;
	overflow: hidden;
	margin-left:1em;
}
.tabsContent .tab1 
{ 
padding-bottom: 10px; 
padding-left: 10px; 
padding-right: 10px; 
display: none; 
color: #ff0000; 
padding-top: 10px; 
}
.tabsContent .block 
{ 
display: block;
} 

.tab 
{
margin-left:0;
} 
.tab UL 
{ 
zoom: 1; 
clear: both; 
} 
.tab UL:after 
{ 
display: block; 
height: 0px; 
visibility: hidden; 
clear: both; 
content: ""; 
} 
.tab UL LI 
{ 
text-align: center; 
line-height: 32px; 
width: 8em; 
display: inline; 
background: #f3f3f3; 
float: left; 
height: 32px; 
color: #222; 
border: 1px solid #fc620f;
font-size: 14px;
} 
.tab UL LI.on 
{ 
background:#fc620f; 
color: #ededed; 
} 

.tab UL LI:first-child 
{
  border-top-left-radius: 5px;
  border-bottom-left-radius:  5px;
}

.tab UL LI:last-child 
{
  border-top-right-radius: 5px;
  border-bottom-right-radius: 5px;
} 

.wrapper 
{
	width: 700px;
	margin-left: 1em;
	text-align: left;
}
h1
 {
	font-size: 21px;
	height: 47px;
	line-height: 47px;
	text-transform: uppercase;
}

/** normal_ws.css **/
body 
{ 
}

p {
  font-size: 14px;; 
  margin-left: 10px;
  font-family: Arial, Helvetica, sans-serif; color: #333333
}

h1 {
  font-size: 14pt; font-weight: bold;
  margin-left: 10px;
  font-family: Arial, Helvetica, sans-serif; color: #0066CC
}

h2 {
	font-size: 12pt; font-weight: bold;
; margin-left: 10px
; font-family: Arial, Helvetica, sans-serif; color: #0066CC
}

h3 {
  font-size: 10pt; font-weight: bold;
  margin-left: 10px;
  font-family: Arial, Helvetica, sans-serif; color: #0066CC
}

h4 {
  font-size: 14px;; font-weight: bold; ; margin-left: 10px ; font-family: Arial, Helvetica, sans-serif; color: #0066CC
}

pre {
  line-height: normal;
  color: #0A0A8C;
font-family: "Courier New", Courier, mono; font-size: 14px;; margin-left: 10px; background-color: #EEEEEE; padding-left: 20px
; padding-top: 5px; padding-bottom: 5px; padding-right: 20px
}

table {
  border: 0px;
}

table.body {
  border: 0px;
  width: 100%;
}

td.title {
  margin-left: 5px;
  background-color: #2C5EA4;
  font-weight: bold;
  white-space: nowrap;
  color: #FFFFFF
}

td.subtitle {
  background-color: #3C6EB4;
  font-style: italic;
  color: #FFFFFF
}

td.head {
  width: 40%;
  font-size: 14px;; 
  font-family: Arial, Helvetica, sans-serif;
  background-color: #E8F8FF;
  white-space: nowrap;
  color: #333333
}

td.head1 {
  width: 20%;
  font-size: 14px;; 
  font-family: Arial, Helvetica, sans-serif;
  background-color: #FFF8E8;
  white-space: nowrap;
  color: #333333
}

td.head2 {
  width: 25%;
  font-size: 14px;; 
  font-family: Arial, Helvetica, sans-serif;
  background-color: #E8F8FF;
  white-space: nowrap;
  color: #333333
}

tr.tr_qos1 {
  font-size: 14px;; 
  font-family: Arial, Helvetica, sans-serif;
  background-color: #FFF8E8;
  white-space: nowrap;
  color: #333333
}

tr.tr_qos2 {
  font-size: 14px;; 
  font-family: Arial, Helvetica, sans-serif;
  background-color: #CCFFCC;
  white-space: nowrap;
  color: #333333
}

td.head_filter {
  width: 5%;
  font-size: 14px;; 
  font-family: Arial, Helvetica, sans-serif;
  background-color: #E8F8FF;
  color: #333333
}

td {
  font-size: 14px;; 
  font-family: Arial, Helvetica, sans-serif;
  color: #333333
}

ol {
  margin-left: 40px; color: #333333; font-family: Arial, Helvetica, sans-serif; font-size: 14px;
}

ul {
  font-size: 14px;; ; margin-left: 30px; font-family: Arial, Helvetica, sans-serif; color: #333333
}

/** Base container **/
.kalendae {
	display: inline-block;zoom:1;*display:inline;
	background:#eee;
	padding:10px;
	margin:5px;
	border-radius:5px;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	font-size:11px;
	font-family:'Helvetica Neue', 'Helvetica';
	cursor:default;
	position:relative;
}

/** Popup Container for Kalendae.Input **/
.kalendae.k-floating {
	position:absolute;
	top:0;
	left:0;
	z-index:100000;
	margin:0;
	box-shadow:0 1px 3px rgba(0,0,0,0.75);
	-moz-box-shadow:0 1px 3px rgba(0,0,0,0.75);
	-webkit-box-shadow:0 1px 3px rgba(0,0,0,0.75);
}

/** Kalendae.Input's popup close button **/
.kalendae .k-btn-close {
	position:absolute;
	top:-8px;
	right:-8px;
	width:16px;
	height:16px;
	background:white;
	border:2px solid #ccc;
	color:#999;
	line-height:17px;
	text-align:center;
	font-size:13px;
	border-radius:10px;
	box-shadow:0 1px 3px rgba(0,0,0,0.75);
	cursor:pointer;
	text-decoration:none;
}
.kalendae .k-btn-close:after {content:"\2716";}
.kalendae .k-btn-close:hover {
	color:#7EA0E2;
	background:white;
	border-color:#7EA0E2;
}

/** Month Container **/
.kalendae .k-calendar {display: inline-block;zoom:1;*display:inline;width:155px;vertical-align:top;}

/** Month Separator **/
.kalendae .k-separator {display: inline-block;zoom:1;*display:inline;width:2px;vertical-align:top;background:#ddd;height:155px;margin:0px 10px;}

/** Month Title Row **/
.kalendae .k-title {text-align:center;white-space:nowrap;position:relative;height:18px;}
.kalendae .k-caption {font-size:12px;line-height:18px;}


/** Month and Year Buttons **/
.kalendae .k-btn-previous-month,
.kalendae .k-btn-next-month,
.kalendae .k-btn-previous-year,
.kalendae .k-btn-next-year {
	width:16px;
	height:16px;
	cursor:pointer;
	position:absolute;
	top:-3px;
	color:#777;
	font-size:26px;
	line-height: 18px;
	font-weight: bold;
	font-family: arial;
	text-decoration:none;
}

.kalendae .k-btn-previous-year {left:0;}
.kalendae .k-btn-previous-month {left:16px;}
.kalendae .k-btn-next-month {right:16px;}
.kalendae .k-btn-next-year {right:0;}

.kalendae .k-btn-previous-month:after {content:"\2039";}
.kalendae .k-btn-next-month:after {content:"\203A";}

.kalendae .k-btn-previous-year:after {content:"\00AB";}
.kalendae .k-btn-next-year:after {content:"\00BB";}

.kalendae .k-btn-previous-month:hover,
.kalendae .k-btn-next-month:hover {color:#7EA0E2;}

.kalendae .k-btn-previous-year:hover,
.kalendae .k-btn-next-year:hover {color:#6FDF81;}

/** Remove extra buttons when calendar shows multiple months **/
.kalendae .k-first-month .k-btn-next-month,
.kalendae .k-middle-month .k-btn-next-month,
.kalendae .k-middle-month .k-btn-previous-month,
.kalendae .k-last-month .k-btn-previous-month,
.kalendae .k-first-month .k-btn-next-year,
.kalendae .k-middle-month .k-btn-next-year,
.kalendae .k-middle-month .k-btn-previous-year,
.kalendae .k-last-month .k-btn-previous-year {display:none;}

/** Disable year nav option **/
.kalendae .k-title.k-disable-year-nav .k-btn-next-year,
.kalendae .k-title.k-disable-year-nav .k-btn-previous-year { display: none; }
.kalendae .k-title.k-disable-year-nav .k-btn-next-month { right: 0; }
.kalendae .k-title.k-disable-year-nav .k-btn-previous-month { left: 0; }

/** Force specific width for month container contents **/
.kalendae .k-title,
.kalendae .k-header,
.kalendae .k-days {
	width:154px;
	display:block;
	overflow:hidden;
}


/** Hide unusable buttons **/
.kalendae.k-disable-next-month-btn .k-btn-next-month,
.kalendae.k-disable-previous-month-btn .k-btn-previous-month,
.kalendae.k-disable-next-year-btn .k-btn-next-year,
.kalendae.k-disable-previous-year-btn .k-btn-previous-year {
	display:none;
}


/** Week columns and day cells **/
.kalendae .k-header span,
.kalendae .k-days span {
	float:left;
	margin:1px 1px;
}

.kalendae .k-header span {
	text-align:center;
	font-weight:bold;
	width:20px;
	padding:1px 0;
	color:#666;
}

.kalendae .k-days span {
	text-align:right;
	width:13px;
	height:1.1em;
	line-height:1em;
	padding:2px 3px 2px 2px;
	border:1px solid transparent;
	border-radius:3px;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
	color:#999;
}

/** Today **/
.kalendae .k-today {
	text-decoration:underline;
}

/** Days inside of the month view **/
.kalendae .k-days span.k-in-month.k-active {
	border-color:#ddd;
	background-color:#fff;
	color:#333;
}
/** Days outside of the month view (before the first day of the month, after the last day of the month) **/
.kalendae .k-days span.k-out-of-month {color:#ddd;}

/** Selectable  **/
.kalendae .k-days span.k-active {
	cursor:pointer;
}

/** Selected day, when outside the selectable area **/
.kalendae .k-days span.k-selected {
	border-color:#1072A5;
	color:#1072A5;
}

/** Selected day, when inside the selectable area **/
.kalendae .k-days span.k-selected.k-active {
	background:#7EA0E2;
	color:white;
}

/** Days between the start and end points on a range, outside of the selectable area **/
.kalendae .k-days span.k-range {
	background:none;
	border-color:#6DD4FE;
}

/** Days between the start and end points on a range, inside of the selectable area **/
.kalendae .k-days span.k-range.k-in-month {
	background:#C4D4F1;
	border-color:#19AEFE;
	color:#333;
}

/** Selectable day, hovered **/
.kalendae .k-days span.k-active:hover {
	border-color:#666;
}

/** Selectable week, hovered **/
.kalendae .k-week:hover span.k-active {
	border-color:#666;
}

.clearfix:after { visibility: hidden; display: block; font-size: 0; content: " "; clear: both; height: 0; }

/*-------------------------------------IE8 ONLY CODE BELOW THIS LINE--------------------------------------------*/

.kalendae.ie8.k-floating {
	border:1px solid #ccc;
}

.kalendae.ie8 .k-btn-close {
	width:20px;
	height:20px;
	border:none;
	background:url('close.png') no-repeat top left;
}
.kalendae.ie8 .k-btn-close:after {display:none;}

.kalendae.ie8 .k-btn-previous-month,
.kalendae.ie8 .k-btn-next-month,
.kalendae.ie8 .k-btn-previous-year,
.kalendae.ie8 .k-btn-next-year {width:16px;height:16px;cursor:pointer;background:#777 url('arrows.png') no-repeat center left;position:absolute;top:0;}

.kalendae.ie8 .k-btn-next-month,
.kalendae.ie8 .k-btn-next-year {background-position:center right;}

.kalendae.ie8 .k-btn-previous-month:hover,
.kalendae.ie8 .k-btn-next-month:hover {background-color:#7EA0E2;}

.kalendae.ie8 .k-btn-previous-year,
.kalendae.ie8 .k-btn-next-year {background-color:#333;}

.kalendae.ie8 .k-btn-previous-year:hover,
.kalendae.ie8 .k-btn-next-year:hover {background-color:#6FDF81;}

.kalendae.ie8 .k-btn-previous-month:after,
.kalendae.ie8 .k-btn-next-month:after,
.kalendae.ie8 .k-btn-previous-year:after,
.kalendae.ie8 .k-btn-next-year:after {display:none;}

/*******************************add by ycf**********************************/
div.button-container{
    display: inline-block;
    margin: 0 9px;
    cursor: pointer;
 /*   height: 38px;
    line-height: 38px;*/
    *display: inline;
    vertical-align: middle;
    padding-top: 20px;
}


div.no-pad-top{
    padding-top: 0px;
}


div.button-container  .button-button{
    /*background-color: #96cc56;*/
    background-color: #199fd7;
    min-width: 90px;
    padding:8px 6px 9px;
    border: 0px;
    border-radius: 3px;
    color: #fff;
    cursor: pointer;
    margin-right: 5px;
    vertical-align: middle;
    
}


div.button-container  .fixed-height{
  height: 36px\9;
}

div.button-container  .button-button-auto{
   
    min-width: auto;
}

div.button-container  .button-button:hover{
    /*background-color: #7eb73d;*/
    background-color: #59b0da;
}

span.button-text{
    line-height: 16px;
    vertical-align: middle;
    width:100%;

div.realtime_lock{
        float: left;
        width: 238px;
        padding-top:20px;
        padding-bottom: 18px;
        border-left: 1px solid #e3e3e3;
        border-right: 1px solid #e3e3e3;
        border-bottom: 1px solid #e3e3e3;
    }

    div.contain div.mt300{
        margin-top: 300px;
    }

    div.door_number{
        text-align: center;
    }

    div.door_number span {
      background-color: #999999;
      border-radius: 10px;
      color: #fff;
      display: inline-block;
      height: 35px;
      line-height: 35px;
      margin-top: 20px;
      width: 90px;
    }

    table.body{
        border: 1px solid #c2c2c2;
        border-collapse: collapse;
    }

    table.body, table.body th, table.body td{
        border: 1px solid #c2c2c2;
     /*   border-collapse: collapse;*/
    }

    div.contain div.noborder{
        border: 0px;
    }

    div.btn-part{
        margin-top: 20px;
    }

    div.left{
        float: left;
        margin: 0px;
        margin-bottom: 10px;
    }

    div.right{
        float: right;
        margin: 0px;
        margin-right: 30px;
        margin-bottom: 10px;
    }

    div.button-container  button.btn-pre{
        margin-right:10px;
    }

    div.button-container  button.btn-next{
        margin-left:10px;
    }

    input.current{
        width:28px;
        height: 28px;
        text-align: center;
        border: 1px solid #aaa;
        margin: 0px 5px;
    }